import React, { useState, useEffect } from 'react'
import Link from 'next/link'
import fetch from 'unfetch'

import LoadingIndicator from '../components/LoadingIndicator.js'
import QuestionSearchResult from '../components/QuestionSearchResult.js'

import styles from './allQuestions.module.css'
import constants from '../constants.json'

export default function AllQuestions({ router }) {
  const [data, setData] = useState(null)
  const [searchTerm, setSearchTerm] = useState('')

  useEffect(() => {
    fetch(`${constants.apiUrl}data.json`, {
      credentials: 'include',
    })
      .then((resp) => {
        return resp.json()
      })
      .then((data) => {
        setData(data)

        router.replace(`${router.asPath.replace('.html', '')}`, undefined, {
          shallow: true,
        })
        const querySearch = router.query.question
          ? decodeURIComponent(router.query.question)
          : ''
        setSearchTerm(querySearch)
      })
  }, [])

  if (data) {
    return (
      <div>
        <div className={styles.searchContainer}>
          <input
            placeholder="Keresés..."
            className={styles.searchBar}
            type="text"
            value={searchTerm}
            onChange={(e) => {
              setSearchTerm(e.target.value)
              router.replace(
                `${router.pathname}${e.target.value &&
                  '?question='}${encodeURIComponent(e.target.value)}`,
                undefined,
                { shallow: true }
              )
            }}
          />
          <button
            onClick={() => {
              setSearchTerm('')
            }}
            className={styles.clearButton}
          >
            X
          </button>
        </div>
        <hr />
        <div>
          <QuestionSearchResult data={data} searchTerm={searchTerm} />
        </div>
      </div>
    )
  } else {
    return <LoadingIndicator />
  }
}
